@@ -2,6 +2,8 @@
 
 #define QT_FEATURE_clang 1
 
+#define QT_FEATURE_qdoc 1
+
 #define QT_FEATURE_clangcpp 1
 
 #define QT_FEATURE_designer 1
@@ -12,8 +14,6 @@
 
 #define QT_FEATURE_linguist 1
 
-#define QT_FEATURE_macdeployqt -1
-
 #define QT_FEATURE_pixeltool 1
 
 #define QT_FEATURE_qdbus 1
@@ -24,9 +24,5 @@
 
 #define QT_FEATURE_qtdiag 1
 
-#define QT_FEATURE_qtpaths 1
-
 #define QT_FEATURE_qtplugininfo 1
 
-#define QT_FEATURE_windeployqt -1
-
